==> surveyplat-proof-common-nfzd-1.0.0-20200930.123212-7-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzJztb.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/2.
 * 举证图斑表
 */
@Table(name = "dcjz_jztb")
public class DcjzJztb {

    @Id
    //举证图斑ID
    private String jztbid;
    //项目id
    private String xmid;
    //图斑编号
    private String tbbh;
    //地类编码
    private String dlbm;
    //地类名称
    private String dlmc;
    //权属性质
    private String qsxz;
    //权属单位代码
    private String qsdwdm;
    //权属单位名称
    private String qsdwmc;
    //图斑面积
    private Float tbmj;
    //建设用地类型
    private String jsydlx;
    //镇/街道
    private String zheng;
    //村/社区
    private String cun;
    //组
    private String zu;
    //门牌号
    private String mph;
    //住宅类型
    private String zzlx;
    //户主姓名
    private String hzxm;
    //身份证号
    private String hzsfzh;
    //政治面貌
    private String hzzzmm;
    //是否本村居民
    private String sfbcjm;
    //项目名称
    private String xmmc;
    //单位名称
    private String xmdwmc;
    //土地主要来源
    private String tdzyly;
    //建房原因
    private String jfyy;
    //房屋用途
    private String fwyt;
    //利用情况
    private String lyqk;
    //开工时间
    private String kgsj;
    //是否扶贫项目
    private String sffpxm;
    //上级部门要求
    private String sjbmyq;
    //上级部门名称
    private String sjbmmc;
    //建设主体名称
    private String jsztmc;
    //建设主体性质
    private String jsztxz;
    //房屋是否出售
    private String fwsfcs;
    //一户一宅
    private String yhyz;
    //一户多宅原因
    private String yhdzyy;
    //与本村农产品相关
    private String ncpxg;
    //占用耕地主要类型
    private String zygdlx;
    //用地手续情况
    private String ydsxqk;
    //无用地手续原因
    private String wydsxyy;
    //房屋总占地面积
    private Float jzzdmj;
    //占用耕地面积
    private Float zygdmj;
    //占用基本农田面积
    private Float zyjbntmj;
    //超宅基地标准面积
    private Float czmj;
    //是否符合城乡规划
    private String sffhcxgh;
    //是否符合总体规划
    private String sffhztgh;
    //是否作出行政处罚
    private String sfxzcf;
    //是否申请法院执行
    private String sfsqfyzx;
    //法院是否受理
    private String fysfsl;
    //中心点X坐标
    private String xzb;
    //中心点Y坐标
    private String yzb;
    //经度
    private Double jd;
    //纬度
    private Double wd;
    //图形
    private String tx;
    //举证状态
    private String jzzt;
    //举证人员
    private String jzry;
    //举证时间
    private Date jzsj;
    //举证签名
    private byte[] jzqm;
    //图斑类型
    private String tblx;
    //举证类型
    private String jzlx;
    //状态
    private String zt;
    //外业备注
    private String wybz;
    //重新举证
    private String cxjz;
    //行政区代码
    private String xzqdm;

    private String sfxzwt;
    private String sfjzjzq;
    private String sfsyssnyd;
    private Float fxtbmj;
    private Float fxzgdmj;
    private Float fxzjbntmj;
    private Float fxzktzmj;
    private String sfgbssnydyt;
    private String ssnydsxbl;

    public String getSfgbssnydyt() {
        return sfgbssnydyt;
    }

    public void setSfgbssnydyt(String sfgbssnydyt) {
        this.sfgbssnydyt = sfgbssnydyt;
    }

    public String getSsnydsxbl() {
        return ssnydsxbl;
    }

    public void setSsnydsxbl(String ssnydsxbl) {
        this.ssnydsxbl = ssnydsxbl;
    }

    public String getJztbid() {
        return jztbid;
    }

    public void setJztbid(String jztbid) {
        this.jztbid = jztbid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getTbbh() {
        return tbbh;
    }

    public void setTbbh(String tbbh) {
        this.tbbh = tbbh;
    }

    public String getDlbm() {
        return dlbm;
    }

    public void setDlbm(String dlbm) {
        this.dlbm = dlbm;
    }

    public String getDlmc() {
        return dlmc;
    }

    public void setDlmc(String dlmc) {
        this.dlmc = dlmc;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getQsdwdm() {
        return qsdwdm;
    }

    public void setQsdwdm(String qsdwdm) {
        this.qsdwdm = qsdwdm;
    }

    public String getQsdwmc() {
        return qsdwmc;
    }

    public void setQsdwmc(String qsdwmc) {
        this.qsdwmc = qsdwmc;
    }

    public Float getTbmj() {
        return tbmj;
    }

    public void setTbmj(Float tbmj) {
        this.tbmj = tbmj;
    }

    public String getJsydlx() {
        return jsydlx;
    }

    public void setJsydlx(String jsydlx) {
        this.jsydlx = jsydlx;
    }

    public String getZheng() {
        return zheng;
    }

    public void setZheng(String zheng) {
        this.zheng = zheng;
    }

    public String getCun() {
        return cun;
    }

    public void setCun(String cun) {
        this.cun = cun;
    }

    public String getZu() {
        return zu;
    }

    public void setZu(String zu) {
        this.zu = zu;
    }

    public String getMph() {
        return mph;
    }

    public void setMph(String mph) {
        this.mph = mph;
    }

    public String getZzlx() {
        return zzlx;
    }

    public void setZzlx(String zzlx) {
        this.zzlx = zzlx;
    }

    public String getHzxm() {
        return hzxm;
    }

    public void setHzxm(String hzxm) {
        this.hzxm = hzxm;
    }

    public String getHzsfzh() {
        return hzsfzh;
    }

    public void setHzsfzh(String hzsfzh) {
        this.hzsfzh = hzsfzh;
    }

    public String getHzzzmm() {
        return hzzzmm;
    }

    public void setHzzzmm(String hzzzmm) {
        this.hzzzmm = hzzzmm;
    }

    public String getSfbcjm() {
        return sfbcjm;
    }

    public void setSfbcjm(String sfbcjm) {
        this.sfbcjm = sfbcjm;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXmdwmc() {
        return xmdwmc;
    }

    public void setXmdwmc(String xmdwmc) {
        this.xmdwmc = xmdwmc;
    }

    public String getTdzyly() {
        return tdzyly;
    }

    public void setTdzyly(String tdzyly) {
        this.tdzyly = tdzyly;
    }

    public String getJfyy() {
        return jfyy;
    }

    public void setJfyy(String jfyy) {
        this.jfyy = jfyy;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public String getLyqk() {
        return lyqk;
    }

    public void setLyqk(String lyqk) {
        this.lyqk = lyqk;
    }

    public String getKgsj() {
        return kgsj;
    }

    public void setKgsj(String kgsj) {
        this.kgsj = kgsj;
    }

    public String getSffpxm() {
        return sffpxm;
    }

    public void setSffpxm(String sffpxm) {
        this.sffpxm = sffpxm;
    }

    public String getSjbmyq() {
        return sjbmyq;
    }

    public void setSjbmyq(String sjbmyq) {
        this.sjbmyq = sjbmyq;
    }

    public String getSjbmmc() {
        return sjbmmc;
    }

    public void setSjbmmc(String sjbmmc) {
        this.sjbmmc = sjbmmc;
    }

    public String getJsztmc() {
        return jsztmc;
    }

    public void setJsztmc(String jsztmc) {
        this.jsztmc = jsztmc;
    }

    public String getJsztxz() {
        return jsztxz;
    }

    public void setJsztxz(String jsztxz) {
        this.jsztxz = jsztxz;
    }

    public String getFwsfcs() {
        return fwsfcs;
    }

    public void setFwsfcs(String fwsfcs) {
        this.fwsfcs = fwsfcs;
    }

    public String getYhyz() {
        return yhyz;
    }

    public void setYhyz(String yhyz) {
        this.yhyz = yhyz;
    }

    public String getYhdzyy() {
        return yhdzyy;
    }

    public void setYhdzyy(String yhdzyy) {
        this.yhdzyy = yhdzyy;
    }

    public String getNcpxg() {
        return ncpxg;
    }

    public void setNcpxg(String ncpxg) {
        this.ncpxg = ncpxg;
    }

    public String getZygdlx() {
        return zygdlx;
    }

    public void setZygdlx(String zygdlx) {
        this.zygdlx = zygdlx;
    }

    public String getYdsxqk() {
        return ydsxqk;
    }

    public void setYdsxqk(String ydsxqk) {
        this.ydsxqk = ydsxqk;
    }

    public String getWydsxyy() {
        return wydsxyy;
    }

    public void setWydsxyy(String wydsxyy) {
        this.wydsxyy = wydsxyy;
    }

    public Float getJzzdmj() {
        return jzzdmj;
    }

    public void setJzzdmj(Float jzzdmj) {
        this.jzzdmj = jzzdmj;
    }

    public Float getZygdmj() {
        return zygdmj;
    }

    public void setZygdmj(Float zygdmj) {
        this.zygdmj = zygdmj;
    }

    public Float getZyjbntmj() {
        return zyjbntmj;
    }

    public void setZyjbntmj(Float zyjbntmj) {
        this.zyjbntmj = zyjbntmj;
    }

    public Float getCzmj() {
        return czmj;
    }

    public void setCzmj(Float czmj) {
        this.czmj = czmj;
    }

    public String getSffhcxgh() {
        return sffhcxgh;
    }

    public void setSffhcxgh(String sffhcxgh) {
        this.sffhcxgh = sffhcxgh;
    }

    public String getSffhztgh() {
        return sffhztgh;
    }

    public void setSffhztgh(String sffhztgh) {
        this.sffhztgh = sffhztgh;
    }

    public String getSfxzcf() {
        return sfxzcf;
    }

    public void setSfxzcf(String sfxzcf) {
        this.sfxzcf = sfxzcf;
    }

    public String getSfsqfyzx() {
        return sfsqfyzx;
    }

    public void setSfsqfyzx(String sfsqfyzx) {
        this.sfsqfyzx = sfsqfyzx;
    }

    public String getFysfsl() {
        return fysfsl;
    }

    public void setFysfsl(String fysfsl) {
        this.fysfsl = fysfsl;
    }

    public String getXzb() {
        return xzb;
    }

    public void setXzb(String xzb) {
        this.xzb = xzb;
    }

    public String getYzb() {
        return yzb;
    }

    public void setYzb(String yzb) {
        this.yzb = yzb;
    }

    public Double getJd() {
        return jd;
    }

    public void setJd(Double jd) {
        this.jd = jd;
    }

    public Double getWd() {
        return wd;
    }

    public void setWd(Double wd) {
        this.wd = wd;
    }

    public String getTx() {
        return tx;
    }

    public void setTx(String tx) {
        this.tx = tx;
    }

    public String getJzzt() {
        return jzzt;
    }

    public void setJzzt(String jzzt) {
        this.jzzt = jzzt;
    }

    public String getJzry() {
        return jzry;
    }

    public void setJzry(String jzry) {
        this.jzry = jzry;
    }

    public Date getJzsj() {
        return jzsj;
    }

    public void setJzsj(Date jzsj) {
        this.jzsj = jzsj;
    }

    public byte[] getJzqm() {
        return jzqm;
    }

    public void setJzqm(byte[] jzqm) {
        this.jzqm = jzqm;
    }

    public String getTblx() {
        return tblx;
    }

    public void setTblx(String tblx) {
        this.tblx = tblx;
    }

    public String getJzlx() {
        return jzlx;
    }

    public void setJzlx(String jzlx) {
        this.jzlx = jzlx;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getWybz() {
        return wybz;
    }

    public void setWybz(String wybz) {
        this.wybz = wybz;
    }

    public String getCxjz() {
        return cxjz;
    }

    public void setCxjz(String cxjz) {
        this.cxjz = cxjz;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getSfxzwt() {
        return sfxzwt;
    }

    public void setSfxzwt(String sfxzwt) {
        this.sfxzwt = sfxzwt;
    }

    public String getSfjzjzq() {
        return sfjzjzq;
    }

    public void setSfjzjzq(String sfjzjzq) {
        this.sfjzjzq = sfjzjzq;
    }

    public String getSfsyssnyd() {
        return sfsyssnyd;
    }

    public void setSfsyssnyd(String sfsyssnyd) {
        this.sfsyssnyd = sfsyssnyd;
    }

    public Float getFxtbmj() {
        return fxtbmj;
    }

    public void setFxtbmj(Float fxtbmj) {
        this.fxtbmj = fxtbmj;
    }

    public Float getFxzgdmj() {
        return fxzgdmj;
    }

    public void setFxzgdmj(Float fxzgdmj) {
        this.fxzgdmj = fxzgdmj;
    }

    public Float getFxzjbntmj() {
        return fxzjbntmj;
    }

    public void setFxzjbntmj(Float fxzjbntmj) {
        this.fxzjbntmj = fxzjbntmj;
    }

    public Float getFxzktzmj() {
        return fxzktzmj;
    }

    public void setFxzktzmj(Float fxzktzmj) {
        this.fxzktzmj = fxzktzmj;
    }
}

==> surveyplat-proof-common-nfzd-1.0.0-20211019.031030-14-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzJztb.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/2.
 * 举证图斑表
 */
@Table(name = "dcjz_jztb")
public class DcjzJztb {

    @Id
    //举证图斑ID
    private String jztbid;
    //项目id
    private String xmid;
    //图斑编号
    private String tbbh;
    //地类编码
    private String dlbm;
    //地类名称
    private String dlmc;
    //权属性质
    private String qsxz;
    //权属单位代码
    private String qsdwdm;
    //权属单位名称
    private String qsdwmc;
    //图斑面积
    private Float tbmj;
    //建设用地类型
    private String jsydlx;
    //镇/街道
    private String zheng;
    //村/社区
    private String cun;
    //组
    private String zu;
    //门牌号
    private String mph;
    //住宅类型
    private String zzlx;
    //户主姓名
    private String hzxm;
    //身份证号
    private String hzsfzh;
    //政治面貌
    private String hzzzmm;
    //是否本村居民
    private String sfbcjm;
    //项目名称
    private String xmmc;
    //单位名称
    private String xmdwmc;
    //土地主要来源
    private String tdzyly;
    //建房原因
    private String jfyy;
    //房屋用途
    private String fwyt;
    //利用情况
    private String lyqk;
    //开工时间
    private String kgsj;
    //是否扶贫项目
    private String sffpxm;
    //上级部门要求
    private String sjbmyq;
    //上级部门名称
    private String sjbmmc;
    //建设主体名称
    private String jsztmc;
    //建设主体性质
    private String jsztxz;
    //房屋是否出售
    private String fwsfcs;
    //一户一宅
    private String yhyz;
    //一户多宅原因
    private String yhdzyy;
    //与本村农产品相关
    private String ncpxg;
    //占用耕地主要类型
    private String zygdlx;
    //用地手续情况
    private String ydsxqk;
    //无用地手续原因
    private String wydsxyy;
    //房屋总占地面积
    private Float jzzdmj;
    //占用耕地面积
    private Float zygdmj;
    //占用可调整面积
    private Float zyktzmj;
    //占用基本农田面积
    private Float zyjbntmj;
    //超宅基地标准面积
    private Float czmj;
    //是否符合城乡规划
    private String sffhcxgh;
    //是否符合总体规划
    private String sffhztgh;
    //是否作出行政处罚
    private String sfxzcf;
    //是否申请法院执行
    private String sfsqfyzx;
    //法院是否受理
    private String fysfsl;
    //中心点X坐标
    private Double xzb;
    //中心点Y坐标
    private Double yzb;
    //经度
    private Double jd;
    //纬度
    private Double wd;
    //图形
    private String tx;
    //举证状态
    private String jzzt;
    //举证人员
    private String jzry;
    //举证时间
    private Date jzsj;
    //举证签名
    private byte[] jzqm;
    //图斑类型
    private String tblx;
    //举证类型
    private String jzlx;
    //状态
    private String zt;
    //外业备注
    private String wybz;
    //重新举证
    private String cxjz;
    //行政区代码
    private String xzqdm;

    private String sfxzwt;
    private String sfjzjzq;
    private String sfsyssnyd;
    private Float fxtbmj;
    private Float fxzgdmj;
    private Float fxzjbntmj;
    private Float fxzktzmj;
    private String sfgbssnydyt;
    private String ssnydsxbl;

    //未占用耕地原因
    private String wzgdyy;
    // 内业填报人员
    private String nytbr;
    //原图斑编号
    private String ytbbh;

    public String getYtbbh() {
        return ytbbh;
    }

    public void setYtbbh(String ytbbh) {
        this.ytbbh = ytbbh;
    }

    public String getNytbr() {
        return nytbr;
    }

    public void setNytbr(String nytbr) {
        this.nytbr = nytbr;
    }

    public String getWzgdyy() {
        return wzgdyy;
    }

    public void setWzgdyy(String wzgdyy) {
        this.wzgdyy = wzgdyy;
    }

    public String getSfgbssnydyt() {
        return sfgbssnydyt;
    }

    public void setSfgbssnydyt(String sfgbssnydyt) {
        this.sfgbssnydyt = sfgbssnydyt;
    }

    public String getSsnydsxbl() {
        return ssnydsxbl;
    }

    public void setSsnydsxbl(String ssnydsxbl) {
        this.ssnydsxbl = ssnydsxbl;
    }

    public String getJztbid() {
        return jztbid;
    }

    public void setJztbid(String jztbid) {
        this.jztbid = jztbid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getTbbh() {
        return tbbh;
    }

    public void setTbbh(String tbbh) {
        this.tbbh = tbbh;
    }

    public String getDlbm() {
        return dlbm;
    }

    public void setDlbm(String dlbm) {
        this.dlbm = dlbm;
    }

    public String getDlmc() {
        return dlmc;
    }

    public void setDlmc(String dlmc) {
        this.dlmc = dlmc;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getQsdwdm() {
        return qsdwdm;
    }

    public void setQsdwdm(String qsdwdm) {
        this.qsdwdm = qsdwdm;
    }

    public String getQsdwmc() {
        return qsdwmc;
    }

    public void setQsdwmc(String qsdwmc) {
        this.qsdwmc = qsdwmc;
    }

    public Float getTbmj() {
        return tbmj;
    }

    public void setTbmj(Float tbmj) {
        this.tbmj = tbmj;
    }

    public String getJsydlx() {
        return jsydlx;
    }

    public void setJsydlx(String jsydlx) {
        this.jsydlx = jsydlx;
    }

    public String getZheng() {
        return zheng;
    }

    public void setZheng(String zheng) {
        this.zheng = zheng;
    }

    public String getCun() {
        return cun;
    }

    public void setCun(String cun) {
        this.cun = cun;
    }

    public String getZu() {
        return zu;
    }

    public void setZu(String zu) {
        this.zu = zu;
    }

    public String getMph() {
        return mph;
    }

    public void setMph(String mph) {
        this.mph = mph;
    }

    public String getZzlx() {
        return zzlx;
    }

    public void setZzlx(String zzlx) {
        this.zzlx = zzlx;
    }

    public String getHzxm() {
        return hzxm;
    }

    public void setHzxm(String hzxm) {
        this.hzxm = hzxm;
    }

    public String getHzsfzh() {
        return hzsfzh;
    }

    public void setHzsfzh(String hzsfzh) {
        this.hzsfzh = hzsfzh;
    }

    public String getHzzzmm() {
        return hzzzmm;
    }

    public void setHzzzmm(String hzzzmm) {
        this.hzzzmm = hzzzmm;
    }

    public String getSfbcjm() {
        return sfbcjm;
    }

    public void setSfbcjm(String sfbcjm) {
        this.sfbcjm = sfbcjm;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXmdwmc() {
        return xmdwmc;
    }

    public void setXmdwmc(String xmdwmc) {
        this.xmdwmc = xmdwmc;
    }

    public String getTdzyly() {
        return tdzyly;
    }

    public void setTdzyly(String tdzyly) {
        this.tdzyly = tdzyly;
    }

    public String getJfyy() {
        return jfyy;
    }

    public void setJfyy(String jfyy) {
        this.jfyy = jfyy;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public String getLyqk() {
        return lyqk;
    }

    public void setLyqk(String lyqk) {
        this.lyqk = lyqk;
    }

    public String getKgsj() {
        return kgsj;
    }

    public void setKgsj(String kgsj) {
        this.kgsj = kgsj;
    }

    public String getSffpxm() {
        return sffpxm;
    }

    public void setSffpxm(String sffpxm) {
        this.sffpxm = sffpxm;
    }

    public String getSjbmyq() {
        return sjbmyq;
    }

    public void setSjbmyq(String sjbmyq) {
        this.sjbmyq = sjbmyq;
    }

    public String getSjbmmc() {
        return sjbmmc;
    }

    public void setSjbmmc(String sjbmmc) {
        this.sjbmmc = sjbmmc;
    }

    public String getJsztmc() {
        return jsztmc;
    }

    public void setJsztmc(String jsztmc) {
        this.jsztmc = jsztmc;
    }

    public String getJsztxz() {
        return jsztxz;
    }

    public void setJsztxz(String jsztxz) {
        this.jsztxz = jsztxz;
    }

    public String getFwsfcs() {
        return fwsfcs;
    }

    public void setFwsfcs(String fwsfcs) {
        this.fwsfcs = fwsfcs;
    }

    public String getYhyz() {
        return yhyz;
    }

    public void setYhyz(String yhyz) {
        this.yhyz = yhyz;
    }

    public String getYhdzyy() {
        return yhdzyy;
    }

    public void setYhdzyy(String yhdzyy) {
        this.yhdzyy = yhdzyy;
    }

    public String getNcpxg() {
        return ncpxg;
    }

    public void setNcpxg(String ncpxg) {
        this.ncpxg = ncpxg;
    }

    public String getZygdlx() {
        return zygdlx;
    }

    public void setZygdlx(String zygdlx) {
        this.zygdlx = zygdlx;
    }

    public String getYdsxqk() {
        return ydsxqk;
    }

    public void setYdsxqk(String ydsxqk) {
        this.ydsxqk = ydsxqk;
    }

    public String getWydsxyy() {
        return wydsxyy;
    }

    public void setWydsxyy(String wydsxyy) {
        this.wydsxyy = wydsxyy;
    }

    public Float getJzzdmj() {
        return jzzdmj;
    }

    public void setJzzdmj(Float jzzdmj) {
        this.jzzdmj = jzzdmj;
    }

    public Float getZygdmj() {
        return zygdmj;
    }

    public void setZygdmj(Float zygdmj) {
        this.zygdmj = zygdmj;
    }

    public Float getZyjbntmj() {
        return zyjbntmj;
    }

    public void setZyjbntmj(Float zyjbntmj) {
        this.zyjbntmj = zyjbntmj;
    }

    public Float getCzmj() {
        return czmj;
    }

    public void setCzmj(Float czmj) {
        this.czmj = czmj;
    }

    public String getSffhcxgh() {
        return sffhcxgh;
    }

    public void setSffhcxgh(String sffhcxgh) {
        this.sffhcxgh = sffhcxgh;
    }

    public String getSffhztgh() {
        return sffhztgh;
    }

    public void setSffhztgh(String sffhztgh) {
        this.sffhztgh = sffhztgh;
    }

    public String getSfxzcf() {
        return sfxzcf;
    }

    public void setSfxzcf(String sfxzcf) {
        this.sfxzcf = sfxzcf;
    }

    public String getSfsqfyzx() {
        return sfsqfyzx;
    }

    public void setSfsqfyzx(String sfsqfyzx) {
        this.sfsqfyzx = sfsqfyzx;
    }

    public String getFysfsl() {
        return fysfsl;
    }

    public void setFysfsl(String fysfsl) {
        this.fysfsl = fysfsl;
    }

    public Double getXzb() {
        return xzb;
    }

    public void setXzb(Double xzb) {
        this.xzb = xzb;
    }

    public Double getYzb() {
        return yzb;
    }

    public void setYzb(Double yzb) {
        this.yzb = yzb;
    }

    public Double getJd() {
        return jd;
    }

    public void setJd(Double jd) {
        this.jd = jd;
    }

    public Double getWd() {
        return wd;
    }

    public void setWd(Double wd) {
        this.wd = wd;
    }

    public String getTx() {
        return tx;
    }

    public void setTx(String tx) {
        this.tx = tx;
    }

    public String getJzzt() {
        return jzzt;
    }

    public void setJzzt(String jzzt) {
        this.jzzt = jzzt;
    }

    public String getJzry() {
        return jzry;
    }

    public void setJzry(String jzry) {
        this.jzry = jzry;
    }

    public Date getJzsj() {
        return jzsj;
    }

    public void setJzsj(Date jzsj) {
        this.jzsj = jzsj;
    }

    public byte[] getJzqm() {
        return jzqm;
    }

    public void setJzqm(byte[] jzqm) {
        this.jzqm = jzqm;
    }

    public String getTblx() {
        return tblx;
    }

    public void setTblx(String tblx) {
        this.tblx = tblx;
    }

    public String getJzlx() {
        return jzlx;
    }

    public void setJzlx(String jzlx) {
        this.jzlx = jzlx;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getWybz() {
        return wybz;
    }

    public void setWybz(String wybz) {
        this.wybz = wybz;
    }

    public String getCxjz() {
        return cxjz;
    }

    public void setCxjz(String cxjz) {
        this.cxjz = cxjz;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getSfxzwt() {
        return sfxzwt;
    }

    public void setSfxzwt(String sfxzwt) {
        this.sfxzwt = sfxzwt;
    }

    public String getSfjzjzq() {
        return sfjzjzq;
    }

    public void setSfjzjzq(String sfjzjzq) {
        this.sfjzjzq = sfjzjzq;
    }

    public String getSfsyssnyd() {
        return sfsyssnyd;
    }

    public void setSfsyssnyd(String sfsyssnyd) {
        this.sfsyssnyd = sfsyssnyd;
    }

    public Float getFxtbmj() {
        return fxtbmj;
    }

    public void setFxtbmj(Float fxtbmj) {
        this.fxtbmj = fxtbmj;
    }

    public Float getFxzgdmj() {
        return fxzgdmj;
    }

    public void setFxzgdmj(Float fxzgdmj) {
        this.fxzgdmj = fxzgdmj;
    }

    public Float getFxzjbntmj() {
        return fxzjbntmj;
    }

    public void setFxzjbntmj(Float fxzjbntmj) {
        this.fxzjbntmj = fxzjbntmj;
    }

    public Float getFxzktzmj() {
        return fxzktzmj;
    }

    public void setFxzktzmj(Float fxzktzmj) {
        this.fxzktzmj = fxzktzmj;
    }

    public Float getZyktzmj() {
        return zyktzmj;
    }

    public void setZyktzmj(Float zykztmj) {
        this.zyktzmj = zykztmj;
    }

}
